---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "edge_firewall_ruleset Resource - terraform-provider-edge"
subcategory: ""
description: |-
  A grouping of firewall rules. The firewall is not enforced unless attached to an interface which can be done with the firewall_ruleset_attachment resource.
---

# edge_firewall_ruleset (Resource)

A grouping of firewall rules. The firewall is not enforced unless attached to an interface which can be done with the `firewall_ruleset_attachment` resource.

## Example Usage

```terraform
resource "edge_firewall_ruleset" "example" {
  name            = "example"
  description     = "drop all traffic on its way to 192.168.2.1/24 over port 80"
  default_action  = "accept"
  default_logging = true

  rule {
    priority    = 10
    description = "ssh"
    action      = "drop" 
    protocol    = "tcp"
    log         = true

    destination = {
      address = "192.168.2.1/24"
      port    = {
          from = 80
          to   = 80
      }
    }
  }
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- **default_action** (String) The default action to take if traffic is not matched by one of the rules in the ruleset. Must be one of `reject`, `drop`, `accept`.
- **name** (String) A unique, human readable name for this ruleset.

### Optional

- **default_logging** (Boolean) Turn on logging for this rule. These rotated logs can be found in /var/log/messages on your router.
- **description** (String) A human readable description for this ruleset.
- **rule** (Block Set) (see [below for nested schema](#nestedblock--rule))

<a id="nestedblock--rule"></a>
### Nested Schema for `rule`

Required:

- **action** (String) The action to take on traffic that matches this rule. Must be one of `reject`, `drop`, `accept`.
- **priority** (Number) The priority of this rule. The higher the priority, the higher the precedence.

Optional:

- **description** (String) A human readable description for this rule.
- **destination** (Attributes) Details about the traffic's destination. If not specified, all sources will be evaluated. (see [below for nested schema](#nestedatt--rule--destination))
- **log** (Boolean) Turn on logging for this rule. These rotated logs can be found in /var/log/messages on your router.
- **protocol** (String) The protocol this rule applies to. If not specified, this rule applies to all protcols. Values prefixed with `!` specifies a _not_ behavior. If `!` is provided, this rule applies to all protocols except this one.
- **source** (Attributes) Details about the traffic's source. If not specified, all sources will be evaluated. (see [below for nested schema](#nestedatt--rule--source))
- **state** (Attributes) This describes the connection state of a packet. (see [below for nested schema](#nestedatt--rule--state))

<a id="nestedatt--rule--destination"></a>
### Nested Schema for `rule.destination`

Optional:

- **address** (String) The cidr this rule applies to. If not provided, it is treated as `0.0.0.0/0`. Conflicts with `address_group`.
- **address_group** (String) The address group this rule applies to. If not provided, all addresses will be matched. Conflicts with `address`.
- **port** (Attributes) A port range. Conflicts with `port_group`. (see [below for nested schema](#nestedatt--rule--destination--port))
- **port_group** (String) The port group this rule applies to. If not provided, all ports will be matched. Conflicts with `port`.

<a id="nestedatt--rule--destination--port"></a>
### Nested Schema for `rule.destination.port`

Optional:

- **from** (Number)
- **to** (Number)



<a id="nestedatt--rule--source"></a>
### Nested Schema for `rule.source`

Optional:

- **address** (String) The cidr this rule applies to. If not provided, it is treated as `0.0.0.0/0`. Conflicts with `address_group`.
- **address_group** (String) The address group this rule applies to. If not provided, all addresses will be matched. Conflicts with `address`.
- **mac** (String)
- **port** (Attributes) A port range. Conflicts with `port_group`. (see [below for nested schema](#nestedatt--rule--source--port))
- **port_group** (String) The port group this rule applies to. If not provided, all ports will be matched. Conflicts with `port`.

<a id="nestedatt--rule--source--port"></a>
### Nested Schema for `rule.source.port`

Optional:

- **from** (Number)
- **to** (Number)



<a id="nestedatt--rule--state"></a>
### Nested Schema for `rule.state`

Optional:

- **established** (Boolean) Match packets that are part of a two-way connection.
- **invalid** (Boolean) Match packets that cannot be identified.
- **new** (Boolean) Match packets creating a new connection.
- **related** (Boolean) Match packets related to established connections.


